use std::path::{Path, PathBuf};
use anyhow::Result;
use std::io::Write;

pub fn create_shortcut(
    target_path: &Path,
    shortcut_name: &str,
    icon_path: Option<&Path>,
) -> Result<()> {
    #[cfg(windows)]
    {
        use std::os::windows::process::CommandExt;
        use std::process::Command;
        
        let desktop_path = dirs::desktop_dir().unwrap_or_else(|| PathBuf::from("."));
        let shortcut_path = desktop_path.join(format!("{}.lnk", shortcut_name));
        
        let powershell_command = format!(
            "$s = (New-Object -ComObject WScript.Shell).CreateShortcut('{}'); $s.TargetPath = '{}'; {}; $s.Save()",
            shortcut_path.to_string_lossy(),
            target_path.to_string_lossy(),
            if let Some(icon) = icon_path {
                format!("$s.IconLocation = '{}'", icon.to_string_lossy())
            } else {
                String::new()
            }
        );
        
        Command::new("powershell")
            .args(["-Command", &powershell_command])
            .creation_flags(0x08000000) // CREATE_NO_WINDOW
            .output()?;
    }
    
    #[cfg(unix)]
    {
        let desktop_path = dirs::desktop_dir().unwrap_or_else(|| PathBuf::from("."));
        let shortcut_path = desktop_path.join(format!("{}.desktop", shortcut_name));
        
        let mut desktop_file = std::fs::File::create(shortcut_path)?;
        
        writeln!(desktop_file, "[Desktop Entry]")?;
        writeln!(desktop_file, "Type=Application")?;
        writeln!(desktop_file, "Name={}", shortcut_name)?;
        writeln!(desktop_file, "Exec={}", target_path.to_string_lossy())?;
        if let Some(icon) = icon_path {
            writeln!(desktop_file, "Icon={}", icon.to_string_lossy())?;
        }
        writeln!(desktop_file, "Terminal=false")?;
        
        // Make the .desktop file executable
        #[cfg(unix)]
        {
            use std::os::unix::fs::PermissionsExt;
            let mut perms = std::fs::metadata(&shortcut_path)?.permissions();
            perms.set_mode(0o755);
            std::fs::set_permissions(&shortcut_path, perms)?;
        }
    }
    
    Ok(())
}