pub mod download_progress {
    use eframe::egui::{Ui, ProgressBar, Color32};
    use crate::app::SinfarInstallerApp;
    use crate::ui::format_duration;

    fn format_bytes(bytes: f64) -> String {
        const KB: f64 = 1024.0;
        const MB: f64 = KB * 1024.0;

        if bytes >= MB {
            format!("{:.1} MB/s", bytes / MB)
        } else if bytes >= KB {
            format!("{:.1} KB/s", bytes / KB)
        } else {
            format!("{:.0} B/s", bytes)
        }
    }

    pub fn render(ui: &mut Ui, app: &mut SinfarInstallerApp) {
        ui.heading("Downloading Sinfar Custom Content");
        ui.add_space(10.0);
        
        ui.vertical(|ui| {
            ui.horizontal(|ui| {
                ui.label("Downloading:");
                ui.add(ProgressBar::new(app.download_progress).show_percentage());
            });
            
            if let Ok(state) = app.download_state.lock() {
                if state.completed {
                    ui.colored_label(Color32::GREEN, "Download Complete");
                } else if app.download_progress > 0.0 && app.download_progress < 1.0 {
                    ui.horizontal(|ui| {
                        ui.label(format_bytes(app.download_speed));
                        ui.label(" • ");
                        ui.label(format_duration(app.estimated_remaining));
                    });
                }
            }
        });

        ui.add_space(10.0);
        
        // Add cancel button only during active download
        if app.download_progress > 0.0 && app.download_progress < 1.0 {
            if ui.button("Cancel Download").clicked() {
                app.cancel_download();
            }
        }
        
        if let Some(error) = &app.download_error {
            ui.colored_label(Color32::RED, format!("Error: {}", error));
            if ui.button("Retry").clicked() {
                app.download_error = None;
                app.download_progress = 0.0;
                app.start_download();
            }
        }
    }
}